==> blesta-5.10.2.zip: blesta/plugins/support_manager/language/it_it/admin_tickets.php <==
<?php
/**
 * Admin Tickets
 *
 * @package blesta
 * @subpackage blesta.language.it_it
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminTickets.search.no_results'] = 'Non ci sono biglietti che corrispondono ai criteri di ricerca.';
$lang['AdminTickets.search.heading_last_reply_date'] = 'Ultima risposta';
$lang['AdminTickets.search.heading_summary'] = 'Sintesi';
$lang['AdminTickets.search.heading_department_name'] = 'Dipartimento';
$lang['AdminTickets.search.heading_status'] = 'Stato';
$lang['AdminTickets.search.heading_priority'] = 'Priorità';
$lang['AdminTickets.search.heading_code'] = 'Numero del biglietto';
$lang['AdminTickets.search.boxtitle_tickets'] = 'Ricerca biglietti per "%1$s"';
$lang['AdminTickets.client.no_results'] = 'Al momento non ci sono biglietti con questo stato.';
$lang['AdminTickets.client.heading_last_reply_date'] = 'Ultima risposta';
$lang['AdminTickets.client.heading_summary'] = 'Sintesi';
$lang['AdminTickets.client.heading_department_name'] = 'Dipartimento';
$lang['AdminTickets.client.heading_priority'] = 'Priorità';
$lang['AdminTickets.client.heading_code'] = 'Numero di biglietto';
$lang['AdminTickets.client.boxtitle_tickets'] = 'Biglietti';
$lang['AdminTickets.client.categorylink_createticket'] = 'Biglietto aperto';
$lang['AdminTickets.client.category_trash'] = 'Rifiuti';
$lang['AdminTickets.client.category_closed'] = 'Chiuso';
$lang['AdminTickets.client.category_on_hold'] = 'In attesa';
$lang['AdminTickets.client.category_in_progress'] = 'In corso';
$lang['AdminTickets.client.category_awaiting_reply'] = 'In attesa della risposta del cliente';
$lang['AdminTickets.client.category_open'] = 'In attesa della risposta del personale';
$lang['AdminTickets.reply.dropzone_remove_file'] = 'Rimuovi file';
$lang['AdminTickets.reply.dropzone_drop_files_here'] = 'Lasciare i file qui per caricarli o Fare clic per selezionare i file';
$lang['AdminTickets.reply.staff_title'] = 'Personale di supporto';
$lang['AdminTickets.reply.system'] = 'Sistema';
$lang['AdminTickets.reply.log_date'] = '%1$s da %2$s %3$s';
$lang['AdminTickets.reply.reply_date'] = 'Su %1$s %2$s %3$s ha risposto';
$lang['AdminTickets.reply.refresh_link'] = 'Fare clic per visualizzare.';
$lang['AdminTickets.reply.refresh'] = 'Ci sono nuove risposte o cambiamenti di stato.';
$lang['AdminTickets.reply.field_actionsubmit'] = 'Vai';
$lang['AdminTickets.reply.field_replysubmit'] = 'Aggiornamento del biglietto';
$lang['AdminTickets.reply.text_add_attachment'] = 'Aggiungi allegato';
$lang['AdminTickets.reply.field_attachments'] = 'Allegati';
$lang['AdminTickets.reply.field_note'] = 'Nota';
$lang['AdminTickets.reply.field_reply'] = 'Risposta';
$lang['AdminTickets.reply.heading_reply'] = 'Aggiungi risposta';
$lang['AdminTickets.reply.text_with_selected'] = 'Con le risposte selezionate, eseguire:';
$lang['AdminTickets.reply.text_add_response'] = 'Inserire una risposta predefinita';
$lang['AdminTickets.reply.heading_date_added'] = 'Data di apertura';
$lang['AdminTickets.reply.heading_status'] = 'Stato';
$lang['AdminTickets.reply.heading_priority'] = 'Priorità';
$lang['AdminTickets.reply.heading_staff_id'] = 'Assegnato a';
$lang['AdminTickets.reply.heading_department'] = 'Dipartimento';
$lang['AdminTickets.reply.heading_client'] = 'Cliente';
$lang['AdminTickets.reply.heading_summary'] = 'Sintesi';
$lang['AdminTickets.reply.boxtitle_reply'] = 'Biglietto #%1$s';
$lang['AdminTickets.add.dropzone_remove_file'] = 'Rimuovi file';
$lang['AdminTickets.add.dropzone_drop_files_here'] = 'Lasciare i file qui per caricarli o Fare clic per selezionare i file';
$lang['AdminTickets.add.text_add_response'] = 'Inserire una risposta predefinita';
$lang['Admintickets.add.client_placeholder'] = 'ID o nome del cliente';
$lang['AdminTickets.add.field_addsubmit'] = 'Biglietto aperto';
$lang['AdminTickets.add.text_add_attachment'] = 'Aggiungi allegato';
$lang['AdminTickets.add.field_details'] = 'Dettagli';
$lang['AdminTickets.add.field_attachments'] = 'Allegati';
$lang['AdminTickets.add.heading_status'] = 'Stato';
$lang['AdminTickets.add.heading_priority'] = 'Priorità';
$lang['AdminTickets.add.heading_staff_id'] = 'Assegnato a';
$lang['AdminTickets.add.heading_department'] = 'Dipartimento';
$lang['AdminTickets.add.heading_client'] = 'Cliente';
$lang['AdminTickets.add.heading_summary'] = 'Sintesi';
$lang['AdminTickets.add.text_no_clients'] = 'Nessun cliente trovato. Riprovare a cercare.';
$lang['AdminTickets.add.heading_search_client'] = 'Ricerca del cliente';
$lang['AdminTickets.add.boxtitle_add'] = 'Biglietto aperto';
$lang['AdminTickets.index.ticket_email'] = '#%1$s %2$s';
$lang['AdminTickets.index.ticket_name'] = '#%1$s %2$s %3$s';
$lang['AdminTickets.index.field_actionsubmit'] = 'Invia';
$lang['AdminTickets.index.text_no_tickets'] = 'Non sono stati trovati biglietti aperti. Provi a cercare di nuovo.';
$lang['AdminTickets.index.ticket_number_placeholder'] = 'Numero di biglietto';
$lang['AdminTickets.index.text_to_status'] = 'Modificare in:';
$lang['AdminTickets.index.text_to_client'] = 'Al cliente:';
$lang['AdminTickets.index.text_into_ticket'] = 'Biglietto d\'ingresso:';
$lang['AdminTickets.index.text_with_selected'] = 'Con i biglietti selezionati, esibirsi:';
$lang['AdminTickets.index.no_results'] = 'Al momento non ci sono biglietti con questo stato.';
$lang['AdminTickets.index.last_reply_by'] = 'da';
$lang['AdminTickets.index.unassigned'] = 'Non assegnato';
$lang['AdminTickets.index.field_last_reply'] = 'Ultima risposta';
$lang['AdminTickets.index.field_assigned_staff'] = 'Assegnato a';
$lang['AdminTickets.index.field_summary'] = 'Sintesi';
$lang['AdminTickets.index.field_department_id'] = 'Dipartimento';
$lang['AdminTickets.index.field_priority'] = 'Priorità';
$lang['AdminTickets.index.field_ticket_number'] = 'Numero di biglietto';
$lang['AdminTickets.index.hours'] = '%1$s ore';
$lang['AdminTickets.index.hour'] = '1 ora';
$lang['AdminTickets.index.minutes'] = '%1$s minuti';
$lang['AdminTickets.index.any'] = 'Qualsiasi';
$lang['AdminTickets.index.heading_last_reply_date'] = 'Ultima risposta';
$lang['AdminTickets.index.heading_assigned_staff'] = 'Assegnato a';
$lang['AdminTickets.index.heading_summary'] = 'Sintesi';
$lang['AdminTickets.index.heading_department_name'] = 'Dipartimento';
$lang['AdminTickets.index.heading_priority'] = 'Priorità';
$lang['AdminTickets.index.heading_client'] = 'Cliente';
$lang['AdminTickets.index.heading_code'] = 'Numero di biglietto';
$lang['AdminTickets.index.boxtitle_tickets'] = 'Biglietti';
$lang['AdminTickets.index.categorylink_createticket'] = 'Biglietto aperto';
$lang['AdminTickets.index.category_trash'] = 'Rifiuti';
$lang['AdminTickets.index.category_closed'] = 'Chiuso';
$lang['AdminTickets.index.category_on_hold'] = 'In attesa';
$lang['AdminTickets.index.category_in_progress'] = 'In corso';
$lang['AdminTickets.index.category_awaiting_reply'] = 'In attesa della risposta del cliente';
$lang['AdminTickets.index.category_open'] = 'In attesa della risposta del personale';
$lang['AdminTickets.text.unassigned'] = 'Non assegnato';
$lang['AdminTickets.search.page_title'] = 'Risultati della ricerca per "%1$s"';
$lang['AdminTickets.reply.page_title'] = 'Manager dell\'assistenza > Biglietto #%1$s';
$lang['AdminTickets.add.page_title'] = 'Gestore dell\'assistenza > Aprire un biglietto';
$lang['AdminTickets.index.page_title'] = 'Gestore dell\'assistenza > Biglietti';
$lang['AdminTickets.!notice.no_departments_staff'] = 'Non sono ancora stati creati personale e/o reparti. Fare clic su %1$s per creare un reparto o su %2$s per assegnare un membro del personale.';
$lang['AdminTickets.!success.ticket_delete'] = 'I biglietti selezionati sono stati eliminati con successo.';
$lang['AdminTickets.!success.ticket_update_status'] = 'I biglietti selezionati sono stati aggiornati con successo.';
$lang['AdminTickets.!success.ticket_reassign'] = 'I biglietti selezionati sono stati riassegnati con successo.';
$lang['AdminTickets.!success.ticket_merge'] = 'I ticket selezionati sono stati uniti con successo al ticket #%1$s.';
$lang['AdminTickets.!success.ticket_split'] = 'Il biglietto #%1$s è stato diviso con successo nel biglietto #%2$s.';
$lang['AdminTickets.!success.ticket_updated'] = 'Il biglietto #%1$s è stato aggiornato con successo.';
$lang['AdminTickets.!success.ticket_created'] = 'Il biglietto #%1$s è stato aperto con successo.';

==> blesta-5.11.4.zip: blesta/plugins/support_manager/language/it_it/admin_tickets.php <==
<?php
/**
 * Admin Tickets
 *
 * @package blesta
 * @subpackage blesta.language.it_it
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminTickets.search.no_results'] = 'Non ci sono biglietti che corrispondono ai criteri di ricerca.';
$lang['AdminTickets.search.heading_last_reply_date'] = 'Ultima risposta';
$lang['AdminTickets.search.heading_summary'] = 'Sintesi';
$lang['AdminTickets.search.heading_department_name'] = 'Dipartimento';
$lang['AdminTickets.search.heading_status'] = 'Stato';
$lang['AdminTickets.search.heading_priority'] = 'Priorità';
$lang['AdminTickets.search.heading_code'] = 'Numero del biglietto';
$lang['AdminTickets.search.boxtitle_tickets'] = 'Ricerca biglietti per "%1$s"';
$lang['AdminTickets.client.no_results'] = 'Al momento non ci sono biglietti con questo stato.';
$lang['AdminTickets.client.heading_last_reply_date'] = 'Ultima risposta';
$lang['AdminTickets.client.heading_summary'] = 'Sintesi';
$lang['AdminTickets.client.heading_department_name'] = 'Dipartimento';
$lang['AdminTickets.client.heading_priority'] = 'Priorità';
$lang['AdminTickets.client.heading_code'] = 'Numero di biglietto';
$lang['AdminTickets.client.boxtitle_tickets'] = 'Biglietti';
$lang['AdminTickets.client.categorylink_createticket'] = 'Biglietto aperto';
$lang['AdminTickets.client.category_trash'] = 'Rifiuti';
$lang['AdminTickets.client.category_closed'] = 'Chiuso';
$lang['AdminTickets.client.category_on_hold'] = 'In attesa';
$lang['AdminTickets.client.category_in_progress'] = 'In corso';
$lang['AdminTickets.client.category_awaiting_reply'] = 'In attesa della risposta del cliente';
$lang['AdminTickets.client.category_open'] = 'In attesa della risposta del personale';
$lang['AdminTickets.reply.dropzone_remove_file'] = 'Rimuovi file';
$lang['AdminTickets.reply.dropzone_drop_files_here'] = 'Lasciare i file qui per caricarli o Fare clic per selezionare i file';
$lang['AdminTickets.reply.staff_title'] = 'Personale di supporto';
$lang['AdminTickets.reply.system'] = 'Sistema';
$lang['AdminTickets.reply.log_date'] = '%1$s da %2$s %3$s';
$lang['AdminTickets.reply.reply_date'] = 'Su %1$s %2$s %3$s ha risposto';
$lang['AdminTickets.reply.refresh_link'] = 'Fare clic per visualizzare.';
$lang['AdminTickets.reply.refresh'] = 'Ci sono nuove risposte o cambiamenti di stato.';
$lang['AdminTickets.reply.field_actionsubmit'] = 'Vai';
$lang['AdminTickets.reply.field_replysubmit'] = 'Aggiornamento del biglietto';
$lang['AdminTickets.reply.text_add_attachment'] = 'Aggiungi allegato';
$lang['AdminTickets.reply.field_attachments'] = 'Allegati';
$lang['AdminTickets.reply.field_note'] = 'Nota';
$lang['AdminTickets.reply.field_reply'] = 'Risposta';
$lang['AdminTickets.reply.heading_reply'] = 'Aggiungi risposta';
$lang['AdminTickets.reply.text_with_selected'] = 'Con le risposte selezionate, eseguire:';
$lang['AdminTickets.reply.text_add_response'] = 'Inserire una risposta predefinita';
$lang['AdminTickets.reply.heading_date_added'] = 'Data di apertura';
$lang['AdminTickets.reply.heading_status'] = 'Stato';
$lang['AdminTickets.reply.heading_priority'] = 'Priorità';
$lang['AdminTickets.reply.heading_staff_id'] = 'Assegnato a';
$lang['AdminTickets.reply.heading_department'] = 'Dipartimento';
$lang['AdminTickets.reply.heading_client'] = 'Cliente';
$lang['AdminTickets.reply.heading_summary'] = 'Sintesi';
$lang['AdminTickets.reply.boxtitle_reply'] = 'Biglietto #%1$s';
$lang['AdminTickets.add.dropzone_remove_file'] = 'Rimuovi file';
$lang['AdminTickets.add.dropzone_drop_files_here'] = 'Lasciare i file qui per caricarli o Fare clic per selezionare i file';
$lang['AdminTickets.add.text_add_response'] = 'Inserire una risposta predefinita';
$lang['Admintickets.add.client_placeholder'] = 'ID o nome del cliente';
$lang['AdminTickets.add.field_addsubmit'] = 'Biglietto aperto';
$lang['AdminTickets.add.text_add_attachment'] = 'Aggiungi allegato';
$lang['AdminTickets.add.field_details'] = 'Dettagli';
$lang['AdminTickets.add.field_attachments'] = 'Allegati';
$lang['AdminTickets.add.heading_status'] = 'Stato';
$lang['AdminTickets.add.heading_priority'] = 'Priorità';
$lang['AdminTickets.add.heading_staff_id'] = 'Assegnato a';
$lang['AdminTickets.add.heading_department'] = 'Dipartimento';
$lang['AdminTickets.add.heading_client'] = 'Cliente';
$lang['AdminTickets.add.heading_summary'] = 'Sintesi';
$lang['AdminTickets.add.text_no_clients'] = 'Nessun cliente trovato. Riprovare a cercare.';
$lang['AdminTickets.add.heading_search_client'] = 'Ricerca del cliente';
$lang['AdminTickets.add.boxtitle_add'] = 'Biglietto aperto';
$lang['AdminTickets.index.ticket_email'] = '#%1$s %2$s';
$lang['AdminTickets.index.ticket_name'] = '#%1$s %2$s %3$s';
$lang['AdminTickets.index.field_actionsubmit'] = 'Invia';
$lang['AdminTickets.index.text_no_tickets'] = 'Non sono stati trovati biglietti aperti. Provi a cercare di nuovo.';
$lang['AdminTickets.index.ticket_number_placeholder'] = 'Numero di biglietto';
$lang['AdminTickets.index.text_to_status'] = 'Modificare in:';
$lang['AdminTickets.index.text_to_client'] = 'Al cliente:';
$lang['AdminTickets.index.text_into_ticket'] = 'Biglietto d\'ingresso:';
$lang['AdminTickets.index.text_with_selected'] = 'Con i biglietti selezionati, esibirsi:';
$lang['AdminTickets.index.no_results'] = 'Al momento non ci sono biglietti con questo stato.';
$lang['AdminTickets.index.last_reply_by'] = 'da';
$lang['AdminTickets.index.unassigned'] = 'Non assegnato';
$lang['AdminTickets.index.field_last_reply'] = 'Ultima risposta';
$lang['AdminTickets.index.field_assigned_staff'] = 'Assegnato a';
$lang['AdminTickets.index.field_summary'] = 'Sintesi';
$lang['AdminTickets.index.field_department_id'] = 'Dipartimento';
$lang['AdminTickets.index.field_priority'] = 'Priorità';
$lang['AdminTickets.index.field_ticket_number'] = 'Numero di biglietto';
$lang['AdminTickets.index.hours'] = '%1$s ore';
$lang['AdminTickets.index.hour'] = '1 ora';
$lang['AdminTickets.index.minutes'] = '%1$s minuti';
$lang['AdminTickets.index.any'] = 'Qualsiasi';
$lang['AdminTickets.index.heading_last_reply_date'] = 'Ultima risposta';
$lang['AdminTickets.index.heading_assigned_staff'] = 'Assegnato a';
$lang['AdminTickets.index.heading_summary'] = 'Sintesi';
$lang['AdminTickets.index.heading_department_name'] = 'Dipartimento';
$lang['AdminTickets.index.heading_priority'] = 'Priorità';
$lang['AdminTickets.index.heading_client'] = 'Cliente';
$lang['AdminTickets.index.heading_code'] = 'Numero di biglietto';
$lang['AdminTickets.index.boxtitle_tickets'] = 'Biglietti';
$lang['AdminTickets.index.categorylink_createticket'] = 'Biglietto aperto';
$lang['AdminTickets.index.category_trash'] = 'Rifiuti';
$lang['AdminTickets.index.category_closed'] = 'Chiuso';
$lang['AdminTickets.index.category_on_hold'] = 'In attesa';
$lang['AdminTickets.index.category_in_progress'] = 'In corso';
$lang['AdminTickets.index.category_awaiting_reply'] = 'In attesa della risposta del cliente';
$lang['AdminTickets.index.category_open'] = 'In attesa della risposta del personale';
$lang['AdminTickets.text.unassigned'] = 'Non assegnato';
$lang['AdminTickets.search.page_title'] = 'Risultati della ricerca per "%1$s"';
$lang['AdminTickets.reply.page_title'] = 'Manager dell\'assistenza > Biglietto #%1$s';
$lang['AdminTickets.add.page_title'] = 'Gestore dell\'assistenza > Aprire un biglietto';
$lang['AdminTickets.index.page_title'] = 'Gestore dell\'assistenza > Biglietti';
$lang['AdminTickets.!notice.no_departments_staff'] = 'Non sono ancora stati creati personale e/o reparti. Fare clic su %1$s per creare un reparto o su %2$s per assegnare un membro del personale.';
$lang['AdminTickets.!success.ticket_delete'] = 'I biglietti selezionati sono stati eliminati con successo.';
$lang['AdminTickets.!success.ticket_update_status'] = 'I biglietti selezionati sono stati aggiornati con successo.';
$lang['AdminTickets.!success.ticket_reassign'] = 'I biglietti selezionati sono stati riassegnati con successo.';
$lang['AdminTickets.!success.ticket_merge'] = 'I ticket selezionati sono stati uniti con successo al ticket #%1$s.';
$lang['AdminTickets.!success.ticket_split'] = 'Il biglietto #%1$s è stato diviso con successo nel biglietto #%2$s.';
$lang['AdminTickets.!success.ticket_updated'] = 'Il biglietto #%1$s è stato aggiornato con successo.';
$lang['AdminTickets.!success.ticket_created'] = 'Il biglietto #%1$s è stato aperto con successo.';
$lang['AdminTickets.reply.text_contacts'] = 'I contatti non selezionati saranno aggiunti automaticamente al ticket se rispondono.';
$lang['AdminTickets.reply.text_add_recipient'] = 'Aggiungi destinatario';
$lang['AdminTickets.reply.heading_contacts'] = 'Contatti';
$lang['AdminTickets.reply.heading_recipients'] = 'Destinatari';
$lang['AdminTickets.add.text_contacts'] = 'I contatti non selezionati saranno aggiunti automaticamente al ticket se rispondono.';
$lang['AdminTickets.add.text_add_recipient'] = 'Aggiungi destinatario';
$lang['AdminTickets.add.heading_contacts'] = 'Contatti';
$lang['AdminTickets.add.heading_recipients'] = 'Destinatari';
